@@ -3,9 +3,8 @@ package PNI;
 use strict;
 use warnings;
 
-our $VERSION = '0.21.1';
+our $VERSION = '0.22.0';
 
-use AnyEvent;
 use Exporter 'import';
 use PNI::Edge;
 use PNI::Finder;
@@ -14,7 +13,6 @@ use PNI::Scenario;
 use Time::HiRes;
 
 # Smiling is better (:
-# use PNI ':-D'; # exports edge, node and task
 our @EXPORT_OK = qw( edge node task );
 our %EXPORT_TAGS = ( '-D' => \@EXPORT_OK );
 
@@ -41,15 +39,6 @@ sub edge {
 
 sub files { $find->files }
 
-sub foo {
-my $self=shift;
-my $t = AnyEvent->timer(
-after => 1,
-interval => 1,
-sub { PNI::task(); }
-);
-}
-
 sub loop {
     while (1) {
         &task;
@@ -57,12 +46,14 @@ sub loop {
     }
 }
 
-sub node { $root->add_node( @_ ) }
+sub node { $root->add_node(@_) }
 
 sub node_list { $find->nodes }
 
 sub root { $root }
 
+sub scen { $root->add_scenario }
+
 sub task { $root->task }
 
 1
@@ -88,39 +79,26 @@ To install PNI module plus a basic set of PNI nodes, do:
     use PNI ':-D'; # imports node, edge and task
 
     my $node = node 'Perlfunc::Print';
-    $node->get_input('list')->set_data('Hello World !');
-    $node->get_input('do_print')->set_data(1);
+    $node->in('list')->data('Hello World !');
+    $node->in('do_print')->data(1);
 
     task; # prints Hello World !
 
 =head1 DESCRIPTION
 
-Hi all! I'm an italian mathematician. 
-I really like Perl philosophy as Larry jokes a lot even if 
-he is one of the masters of hacking.
+Hi all! I'm an italian mathematician.  I really like Perl philosophy as Larry jokes a lot even if he is one of the masters of hacking.
 
 PNI stands for Perl Node Interface.
 
-It is my main project, my contribution to the great Perl community. 
-Node programming is really interesting since makes possible to realize a program
-even if you have no idea about programming. 
+It is my main project, my contribution to the great Perl community. Node programming is really interesting since makes possible to realize a program even if you have no idea about programming. 
 
-Think about genetic researchers, for example. They need to focus on protein 
-chains, not on what a package is. Maybe they can do an extra effort and say the
-world "variable" or "string" or even "regular expression" and that makes them 
-proud, but they don't care about inheritance.
+Think about genetic researchers, for example. They need to focus on protein chains, not on what a package is. Maybe they can do an extra effort and say the world "variable" or "string" or even "regular expression" and that makes them proud, but they don't care about inheritance.
 
-They want things working and they need Perl ... 
+They want things working and they need Perl ... but if you say Strawberry they think about yogurt, not about Windows.
 
-but if you say Strawberry they think about yogurt, not about Windows.
+There are a lot of node programming languages (VVVV, Puredata, Max/Msp) but normally they target artists and interaction designers. I saw a lot of vjs and musicians do really complex programs with those software, and they never wrote a line of code.
 
-There are a lot of node programming languages (VVVV, Puredata, Max/Msp) but
-normally they target artists and interaction designers. I saw a lot of vjs and
-musicians do really complex programs with those software, and they never wrote 
-a line of code.
-
-This is my effort to provide a node interface that brings Perl power 
-to people who don't know the Perl language.
+This is my effort to provide a node interface that brings Perl power to people who don't know the Perl language.
 
 Blah blah blah. ( this was the h2xs command :-)
 
@@ -131,8 +109,8 @@ Blah blah blah. ( this was the h2xs command :-)
     my $source_node = PNI::node 'Some::Node';
     my $target_node = PNI::node 'Another::Node';
 
-    my $edge = PNI::edge $source_node    => $target_node , 
-               'source_output_name' => 'target_input_name';
+    my $edge = PNI::edge $source_node         => $target_node , 
+                         'source_output_name' => 'target_input_name';
 
 Connects an output of a node to an input of another node.
 
@@ -144,15 +122,13 @@ Returns a list of all .pni files in PNI.pm install dir and subdirs.
 
 =head2 node
 
-Creates a node by its PNI type, that is the name of a package under the
-PNI::Node namespace, and adds it to the root scenario. If you write
-
+    # Load PNI::Node::Foo::Bar node. 
     my $node = PNI::node 'Foo::Bar';
 
-PNI loads and inits PNI::Node::Foo::Bar node. 
-
-If no PNI type is passed, and you just write
+Creates a node by its PNI type, that is the name of a package under the
+PNI::Node namespace, and adds it to the root scenario.
 
+    # No PNI type returns an empty node.
     my $node = PNI::node;
     
 PNI creates an empty node.
@@ -165,13 +141,6 @@ Returns a list of available PNI nodes.
 
 This method delegates to L<PNI::Finder> C<nodes> method.
 
-=head2 task
-
-    PNI::task;
-
-Calls the task method for every loaded node.
-This method delegates to the root scenario task method.
-
 =head2 loop
 
     PNI::loop;
@@ -184,11 +153,22 @@ Starts the PNI main loop. It keeps calling C<task> as fast as it can.
 
 Returns the root PNI::Scenario.
 
+=head2 scen
+
+    my $scen = PNI::scen;
+
+=head2 task
+
+    PNI::task;
+
+Calls the task method for every loaded node.
+This method delegates to the root scenario task method.
+
 =head1 SEE ALSO
 
 L<PNI::Core>
 
-L<PNI::GUI::Tk>
+L<PNI::GUI>
 
 L<PNI blog|http://perl-node-interface.blogspot.com>
 
